#!/usr/bin/env python3.6
# -*- coding: utf-8 -*-
from distutils.core import setup
setup(
        name        = 'dc_nester',
        version     = '1.0.0',
        py_modules  = ['nester'],
        author      = 'shyreckdc',
        author_email= 'shyreckdc@gmail.com',
        url         = 'http://www.headfirstlabs.com',
        description = 'A printer for nested lists',
)
      
